@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity utilities */
 
 /* 
@@ -48,28 +50,28 @@ void meta_fatal      (const char *format,
 
 typedef enum
 {
-  META_DEBUG_FOCUS        = 1 << 0,
-  META_DEBUG_WORKAREA     = 1 << 1,
-  META_DEBUG_STACK        = 1 << 2,
-  META_DEBUG_THEMES       = 1 << 3,
-  META_DEBUG_SM           = 1 << 4,
-  META_DEBUG_EVENTS       = 1 << 5,
-  META_DEBUG_WINDOW_STATE = 1 << 6,
-  META_DEBUG_WINDOW_OPS   = 1 << 7,
-  META_DEBUG_GEOMETRY     = 1 << 8,
-  META_DEBUG_PLACEMENT    = 1 << 9,
-  META_DEBUG_PING         = 1 << 10,
-  META_DEBUG_XINERAMA     = 1 << 11,
-  META_DEBUG_KEYBINDINGS  = 1 << 12,
-  META_DEBUG_SYNC         = 1 << 13,
-  META_DEBUG_ERRORS       = 1 << 14,
-  META_DEBUG_STARTUP      = 1 << 15,
-  META_DEBUG_PREFS        = 1 << 16,
-  META_DEBUG_GROUPS       = 1 << 17,
-  META_DEBUG_RESIZING     = 1 << 18,
-  META_DEBUG_SHAPES       = 1 << 19,
-  META_DEBUG_COMPOSITOR   = 1 << 20
-
+  META_DEBUG_FOCUS           = 1 << 0,
+  META_DEBUG_WORKAREA        = 1 << 1,
+  META_DEBUG_STACK           = 1 << 2,
+  META_DEBUG_THEMES          = 1 << 3,
+  META_DEBUG_SM              = 1 << 4,
+  META_DEBUG_EVENTS          = 1 << 5,
+  META_DEBUG_WINDOW_STATE    = 1 << 6,
+  META_DEBUG_WINDOW_OPS      = 1 << 7,
+  META_DEBUG_GEOMETRY        = 1 << 8,
+  META_DEBUG_PLACEMENT       = 1 << 9,
+  META_DEBUG_PING            = 1 << 10,
+  META_DEBUG_XINERAMA        = 1 << 11,
+  META_DEBUG_KEYBINDINGS     = 1 << 12,
+  META_DEBUG_SYNC            = 1 << 13,
+  META_DEBUG_ERRORS          = 1 << 14,
+  META_DEBUG_STARTUP         = 1 << 15,
+  META_DEBUG_PREFS           = 1 << 16,
+  META_DEBUG_GROUPS          = 1 << 17,
+  META_DEBUG_RESIZING        = 1 << 18,
+  META_DEBUG_SHAPES          = 1 << 19,
+  META_DEBUG_COMPOSITOR      = 1 << 20,
+  META_DEBUG_EDGE_RESISTANCE = 1 << 21
 } MetaDebugTopic;
 
 void meta_topic_real      (MetaDebugTopic topic,
@@ -93,6 +95,8 @@ const char* meta_gravity_to_string (int gravity);
 
 char* meta_g_utf8_strndup (const gchar *src, gsize n);
 
+void  meta_free_gslist_and_elements (GSList *list_to_deep_free);
+
 /* To disable verbose mode, we make these functions into no-ops */
 #ifdef WITH_VERBOSE_MODE
 
